=== modified file 'bzrlib/plugins/launchpad/lp_registration.py'
--- bzrlib/plugins/launchpad/lp_registration.py	2006-10-11 23:08:27 +0000
+++ bzrlib/plugins/launchpad/lp_registration.py	2007-10-10 01:25:42 +0000
@@ -69,25 +69,29 @@
         else:
             return self.DEFAULT_SERVICE_URL
 
-    def get_proxy(self):
+    def get_proxy(self, authenticated):
         """Return the proxy for XMLRPC requests."""
-        # auth info must be in url
-        # TODO: if there's no registrant email perhaps we should just connect
-        # anonymously?
-        scheme, hostinfo, path = urlsplit(self.service_url)[:3]
-        assert '@' not in hostinfo
-        assert self.registrant_email is not None
-        assert self.registrant_password is not None
-        # TODO: perhaps fully quote the password to make it very slightly
-        # obscured
-        # TODO: can we perhaps add extra Authorization headers directly to the 
-        # request, rather than putting this into the url?  perhaps a bit more 
-        # secure against accidentally revealing it.  std66 s3.2.1 discourages putting
-        # the password in the url.
-        hostinfo = '%s:%s@%s' % (urllib.quote(self.registrant_email),
-                                 urllib.quote(self.registrant_password),
-                                 hostinfo)
-        url = urlunsplit((scheme, hostinfo, path, '', ''))
+        if authenticated:
+            # auth info must be in url
+            # TODO: if there's no registrant email perhaps we should
+            # just connect anonymously?
+            scheme, hostinfo, path = urlsplit(self.service_url)[:3]
+            assert '@' not in hostinfo
+            assert self.registrant_email is not None
+            assert self.registrant_password is not None
+            # TODO: perhaps fully quote the password to make it very slightly
+            # obscured
+            # TODO: can we perhaps add extra Authorization headers
+            # directly to the request, rather than putting this into
+            # the url?  perhaps a bit more secure against accidentally
+            # revealing it.  std66 s3.2.1 discourages putting the
+            # password in the url.
+            hostinfo = '%s:%s@%s' % (urllib.quote(self.registrant_email),
+                                     urllib.quote(self.registrant_password),
+                                     hostinfo)
+            url = urlunsplit((scheme, hostinfo, path, '', ''))
+        else:
+            url = self.service_url
         return xmlrpclib.ServerProxy(url, transport=self.transport)
 
     def gather_user_credentials(self):
@@ -99,8 +103,8 @@
                     self.registrant_email
             self.registrant_password = getpass(prompt)
 
-    def send_request(self, method_name, method_params):
-        proxy = self.get_proxy()
+    def send_request(self, method_name, method_params, authenticated):
+        proxy = self.get_proxy(authenticated)
         assert method_name
         method = getattr(proxy, method_name)
         try:
@@ -126,6 +130,7 @@
 
     # Set this to the XMLRPC method name.
     _methodname = None
+    _authenticated = True
 
     def _request_params(self):
         """Return the arguments to pass to the method"""
@@ -137,7 +142,8 @@
         :param service: LaunchpadService indicating where to send
             the request and the authentication credentials.
         """
-        return service.send_request(self._methodname, self._request_params())
+        return service.send_request(self._methodname, self._request_params(),
+                                    self._authenticated)
 
 
 class DryRunLaunchpadService(LaunchpadService):
@@ -146,7 +152,7 @@
     The dummy service does not need authentication.
     """
 
-    def send_request(self, method_name, method_params):
+    def send_request(self, method_name, method_params, authenticated):
         pass
 
     def gather_user_credentials(self):

=== modified file 'bzrlib/plugins/launchpad/test_register.py'
--- bzrlib/plugins/launchpad/test_register.py	2007-07-04 09:27:22 +0000
+++ bzrlib/plugins/launchpad/test_register.py	2007-10-10 01:25:42 +0000
@@ -110,10 +110,11 @@
 
 class MockLaunchpadService(LaunchpadService):
 
-    def send_request(self, method_name, method_params):
+    def send_request(self, method_name, method_params, authenticated):
         """Stash away the method details rather than sending them to a real server"""
         self.called_method_name = method_name
         self.called_method_params = method_params
+        self.called_authenticated = authenticated
 
 
 class TestBranchRegistration(TestCase):
@@ -186,10 +187,11 @@
         """Send registration to mock server"""
         test_case = self
         class MockRegistrationService(MockLaunchpadService):
-            def send_request(self, method_name, method_params):
+            def send_request(self, method_name, method_params, authenticated):
                 test_case.assertEquals(method_name, "register_branch")
                 test_case.assertEquals(list(method_params),
                         ['url', 'name', 'title', 'description', 'email', 'name'])
+                test_case.assertEquals(authenticated, True)
                 return 'result'
         service = MockRegistrationService()
         rego = BranchRegistrationRequest('url', 'name', 'title',
@@ -201,10 +203,11 @@
         """Send registration to mock server"""
         test_case = self
         class MockRegistrationService(MockLaunchpadService):
-            def send_request(self, method_name, method_params):
+            def send_request(self, method_name, method_params, authenticated):
                 test_case.assertEquals(method_name, "register_branch")
                 test_case.assertEquals(list(method_params),
                         ['http://server/branch', 'branch', '', '', '', ''])
+                test_case.assertEquals(authenticated, True)
                 return 'result'
         service = MockRegistrationService()
         rego = BranchRegistrationRequest('http://server/branch')
@@ -215,10 +218,11 @@
         """Send bug-branch link to mock server"""
         test_case = self
         class MockService(MockLaunchpadService):
-            def send_request(self, method_name, method_params):
+            def send_request(self, method_name, method_params, authenticated):
                 test_case.assertEquals(method_name, "link_branch_to_bug")
                 test_case.assertEquals(list(method_params),
                         ['http://server/branch', 1234, ''])
+                test_case.assertEquals(authenticated, True)
                 return 'http://launchpad.net/bug/1234'
         service = MockService()
         rego = BranchBugLinkRequest('http://server/branch', 1234)

